#!/usr/bin/env python
################################################################################
#	PlotFile.py	Signal plotter
#			T.Barnaby,	BEAM Ltd,	2006-02-10
################################################################################
#

import sys
import getopt
import math
import Gnuplot
import array

def sigFileReadAscii(fileName, numSamples):
	d = Numeric.zeros(numSamples, Numeric.Float32);
	f = open(fileName);
	for i in range(0, numSamples):
		l = f.readline();
		if(l == ""):
			break;
		d[i] = float(l);
	
	return d[0:i];

def sigFileRead(fileName, numSamples):
	f = open(fileName, "r");
	s = os.fstat(f.fileno());
	if(numSamples > (s.st_size / (24 * 4))):
		numSamples = s.st_size / (24 * 4);
	
	d = array.array("f");
	d.fromfile(f, 24 * numSamples);
	
	sig24 = Numeric.zeros((24, numSamples), Numeric.Float32);
	for i in range(0, numSamples):
		for c in range(0, 24):
			sig24[c][i] = d[i * 24 + c];
	
	return sig24;

def plotSig1(fileName, toFile=""):
	g = Gnuplot.Gnuplot();

	g('set multiplot');
	g('set format x ""');
	g('set lmargin 8');
	g('set bmargin 0');
	g('set tmargin 1');
	g('set grid noytics xtics');
	g('set data style lines');


#	g('set size 1.0,1.0');
	g('set data style lines');
	g('set grid');
	g('set mouse');
	if(toFile != ""):
		g('set term png');
		g("set output '" + toFile + "'");
		

	d1 = Gnuplot.Data(sig);
	g('set xlabel "Sample"');
	if(sigRange != ""):
		g('set xrange [' + sigRange + ']');
	g.plot(d1);
	
	if(toFile == ""):
		raw_input('Please press return to continue...\n');

def plotSig(fileName, toFile=""):
	g = Gnuplot.Gnuplot();

	g('set multiplot');
	g('set format x ""');
	g('set lmargin 8');
	g('set bmargin 0');
	g('set tmargin 1');
	g('set grid noytics xtics');
	g('set data style lines');

	g.plot("diag_injection_0g.txt");
	
	if(toFile == ""):
		raw_input('Please press return to continue...\n');

def usage():
	print "Usage: filePlot.py [ -p <file> ] <signal file>";
	print "		-p <file>	- Create graphics file (.png)"
	
def main():
	toFile		= "";
				
	try:
		opts, args = getopt.getopt(sys.argv[1:], "p:");
	except getopt.GetoptError:
        	# print help information and exit:
        	usage();
        	sys.exit(1);

	for o in opts:
		if(o[0] == "-p"):
			toFile = o[1];
		else:
			usage();

	if(len(args) != 1):
		usage();
		sys.exit(1);

	plotSig(args[0]);
		
	sys.exit(0);
	
if __name__ == "__main__":
	main();



#############################################################################
#	base.cc	Produced by Bidl
#############################################################################
#

import sys;

sys.path.extend(['/usr/beam/lib']);

from Beam import *;

import libBase;

# BObjDInfo Object Implementation
class BObjDInfo(BObjData):
	def __init__(s):
		BObjData.__init__(s);
		s.type = 0;
		s.description = BObjString();

# BObjDTodo Object Implementation
class BObjDTodo(BObjData):
	def __init__(s):
		BObjData.__init__(s);
		s.type = 0;
		s.priority = BObjInt();
		s.done = BObjInt();
		s.startDate = BObjDate();
		s.endDate = BObjDate();
		s.description = BObjString();

# BObjDAddress Object Implementation
class BObjDAddress(BObjData):
	def __init__(s):
		BObjData.__init__(s);
		s.type = 0;
		s.firstName = BObjString();
		s.lastName = BObjString();
		s.company = BObjString();
		s.address = BObjString();
		s.postCode = BObjString();
		s.tel = BObjString();
		s.mobile = BObjString();
		s.fax = BObjString();
		s.email = BObjString();
		s.web = BObjString();
		s.groups = BObjString();
		s.christmas = BObjString();
		s.misc = BObjString();
		s.telWork = BObjString();

# BObjDTest Object Implementation
class BObjDTest(BObjData):
	def __init__(s):
		BObjData.__init__(s);
		s.type = 0;
		s.test1 = BObjString();
		s.test2 = BObjString();

# BObjDWhatsOn Object Implementation
class BObjDWhatsOn(BObjData):
	def __init__(s):
		BObjData.__init__(s);
		s.type = 0;
		s.date = BObjDate();
		s.dateLast = BObjDate();
		s.tcGroup = BObjString();
		s.startTime = BObjString();
		s.startPlace = BObjString();
		s.rideLength = BObjString();
		s.ease = BObjString();
		s.description = BObjString();
		s.who = BObjString();
		s.tel = BObjString();
		s.email = BObjString();
		s.web = BObjString();

# BObjDMttest Object Implementation
class BObjDMttest(BObjData):
	def __init__(s):
		BObjData.__init__(s);
		s.type = 0;
		s.field1 = BObjString();
		s.field2 = BObjString();

# Item Object Implementation
class Item(BObjData):
	def __init__(s):
		BObjData.__init__(s);
		s.type = 0;
		s.qty = BObjInt();
		s.info = BObjString();

# Despatch Object Implementation
class Despatch(BObjData):
	def __init__(s):
		BObjData.__init__(s);
		s.type = 0;
		s.start = BObjInt();
		s.item1 = Item();
		s.item2 = Item();

